'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _util = require('../util');

var _util2 = _interopRequireDefault(_util);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var attributeNames = {
  If: 'data-if',
  ElseIf: 'data-else-if',
  Else: 'data-else'
};

var conditionalSyntax = function conditionalSyntax(types, nodePath, attributeName) {
  var expression = _util2.default.getAttribute(nodePath, attributeName).value.expression;
  var index = _util2.default.getAttributeIndex(nodePath, attributeName);

  if (!expression || index === -1) {
    throw new TypeError('Conditional SyntaxError');
  }

  // 무한 루프를 피하기 위해 사용됩니다.
  // to avoid infinite loop.
  _util2.default.removeAttribute(nodePath, index);

  return { expression: expression, index: index };
};

var elseSyntax = function elseSyntax(types, nodePath, conditioned) {
  if (types.isJSXElement(nodePath.parent)) {
    var nodes = _util2.default.getBetweenNodes(types, nodePath.parent, attributeNames.If, attributeNames.Else);
    if (nodes) {
      nodes = nodes[0];

      if (types.isJSXElement(nodes)) {
        conditioned.alternate = nodes;
      }
    }
  }
};

var elseIfSyntax = function elseIfSyntax(types, nodePath) {
  var rootConditional = void 0;
  if (types.isJSXElement(nodePath.parent)) {
    (function () {
      var conditional = void 0;

      var nodes = _util2.default.getBetweenNodes(types, nodePath.parent, attributeNames.If, attributeNames.ElseIf);
      nodes.forEach(function (node) {
        var _conditionalSyntax = conditionalSyntax(types, node, attributeNames.ElseIf),
            expression = _conditionalSyntax.expression;

        if (!rootConditional) {
          rootConditional = types.conditionalExpression(expression, node, types.nullLiteral());

          conditional = rootConditional;
        } else {
          conditional.alternate = types.conditionalExpression(expression, node, types.nullLiteral());

          conditional = conditional.alternate;
        }
      });
    })();
  }

  return rootConditional;
};

var ifSyntax = function ifSyntax(types, nodePath) {
  var _conditionalSyntax2 = conditionalSyntax(types, nodePath, attributeNames.If),
      expression = _conditionalSyntax2.expression;

  var conditional = types.conditionalExpression(expression, nodePath.node, types.nullLiteral());

  var elseIfExpression = elseIfSyntax(types, nodePath);
  if (elseIfExpression) {
    conditional.alternate = elseIfExpression;
  }

  var elseConditional = conditional;
  while (!types.isNullLiteral(elseConditional.alternate)) {
    elseConditional = elseConditional.alternate;
  }

  elseSyntax(types, nodePath, elseConditional);

  return conditional;
};

exports.default = ifSyntax;